@@ -11,9 +11,14 @@
 #include "biji-info-set.h"
 #include "biji-note-obj.h"
 
+
+#include <libedataserver/libedataserver.h> /* ESourceRegistry */
+
 #define GOA_API_IS_SUBJECT_TO_CHANGE
 #include <goa/goa.h>
 
+
+
 G_BEGIN_DECLS
 
 /* The flag tells if view should reload the whole model or not */
@@ -62,25 +67,31 @@ struct _BijiManager
 
 
 
-GType biji_manager_get_type (void) G_GNUC_CONST; 
+GType biji_manager_get_type (void) G_GNUC_CONST;
 
 
 
-BijiManager    *biji_manager_new                   (GFile *location,
-                                                       GdkRGBA *color,
-                                                       GError **error);
+BijiManager     *biji_manager_new                   (GFile *location,
+                                                    GdkRGBA *color,
+                                                    GError **error);
 
 
 void             biji_manager_import_uri            (BijiManager *manager,
-                                                       gchar *target_provider_id,
-                                                       gchar *uri);
+                                                     gchar *target_provider_id,
+                                                     gchar *uri);
+
+
+
+void             biji_manager_add_e_source_extension_memo
+                                                    (BijiManager *self,
+                                                     ESource *source);
 
 
 void             biji_manager_add_goa_object        (BijiManager *manager,
-                                                       GoaObject *object);
+                                                     GoaObject *object);
 
-/* <ProviderInfo*> */
-GList           *biji_manager_get_providers         (BijiManager *manager);
+
+GList           *biji_manager_get_providers         (BijiManager *manager); /* <ProviderInfo*> */
 
 
 #if BUILD_ZEITGEIST
@@ -91,12 +102,13 @@ TrackerSparqlConnection
                 *biji_manager_get_tracker_connection (BijiManager *manager);
 
 
+
 void             biji_manager_get_default_color     (BijiManager *manager,
-                                                       GdkRGBA *color);
+                                                     GdkRGBA *color);
 
 
 gchar           *biji_manager_get_unique_title      (BijiManager *manager,
-                                                       const gchar *title);
+                                                     const gchar *title);
 
 
 gboolean         biji_manager_add_item                (BijiManager *manager,
@@ -111,12 +123,8 @@ void             biji_manager_notify_changed        (BijiManager           *mana
                                                      BijiItem              *item);
 
 
-gboolean         biji_manager_remove_item           (BijiManager *manager,
-                                                       BijiItem *item);
-
-
 BijiItem        *biji_manager_get_item_at_path      (BijiManager *manager,
-                                                       const gchar *path);
+                                                     const gchar *path);
 
 
 /* Get all items, either notes or notebooks
@@ -128,30 +136,21 @@ GList           *biji_manager_get_items             (BijiManager         *manage
 
 
 
-void             biji_manager_load_archives          (BijiManager        *manager);
-
-
-
 void             biji_manager_empty_bin              (BijiManager        *manager);
 
 
-// deprecated - instead we'll use new import / providers facilities
-BijiNoteObj     *biji_note_get_new_from_file          (BijiManager *manager,
-                                                       const gchar* tomboy_format_note_path);
-
-
 
 BijiNoteObj     *biji_manager_note_new              (BijiManager *manager,
-                                                       gchar        *str,
-                                                       gchar        *provider_id);
+                                                     gchar        *str,
+                                                     gchar        *provider_id);
 
 
 BijiNoteObj     *biji_manager_note_new_full         (BijiManager *manager,
-                                                       gchar        *provider_id,
-                                                       gchar        *suggested_path,
-                                                       BijiInfoSet  *info,
-                                                       gchar        *html,
-                                                       GdkRGBA      *color);
+                                                     gchar        *provider_id,
+                                                     gchar        *suggested_path,
+                                                     BijiInfoSet  *info,
+                                                     gchar        *html,
+                                                     GdkRGBA      *color);
 
 
 G_END_DECLS
